const React = require('react')
const PropTypes = require('prop-types')

const colors = require('material-ui/styles/colors')
const Checkbox = require('material-ui/Checkbox').default
const RaisedButton = require('material-ui/RaisedButton').default
const Heading = require('../components/heading')
const PathSelector = require('../components/path-selector')

const { dispatch } = require('../lib/dispatcher')
const config = require('../../config')

class PreferencesPage extends React.Component {
  constructor (props) {
    super(props)

    this.handleDownloadPathChange =
      this.handleDownloadPathChange.bind(this)

    this.handleOpenExternalPlayerChange =
      this.handleOpenExternalPlayerChange.bind(this)

    this.handleExternalPlayerPathChange =
      this.handleExternalPlayerPathChange.bind(this)

    this.handleStartupChange =
      this.handleStartupChange.bind(this)

    this.handleSoundNotificationsChange =
      this.handleSoundNotificationsChange.bind(this)
  }

  downloadPathSelector () {
    return (
      React.createElement( Preference, null,
        React.createElement( PathSelector, {
          dialog: {
            title: 'Select download directory',
            properties: ['openDirectory']
          }, onChange: this.handleDownloadPathChange, title: 'Download location', value: this.props.state.saved.prefs.downloadPath })
      )
    )
  }

  handleDownloadPathChange (filePath) {
    dispatch('updatePreferences', 'downloadPath', filePath)
  }

  openExternalPlayerCheckbox () {
    return (
      React.createElement( Preference, null,
        React.createElement( Checkbox, {
          className: 'control', checked: !this.props.state.saved.prefs.openExternalPlayer, label: 'Play torrent media files using WebTorrent', onCheck: this.handleOpenExternalPlayerChange })
      )
    )
  }

  handleOpenExternalPlayerChange (e, isChecked) {
    dispatch('updatePreferences', 'openExternalPlayer', !isChecked)
  }

  highestPlaybackPriorityCheckbox () {
    return (
      React.createElement( Preference, null,
        React.createElement( Checkbox, {
          className: 'control', checked: this.props.state.saved.prefs.highestPlaybackPriority, label: 'Highest Playback Priority', onCheck: this.handleHighestPlaybackPriorityChange }),
        React.createElement( 'p', null, "Pauses all active torrents to allow playback to use all of the available bandwidth." )
      )
    )
  }

  handleHighestPlaybackPriorityChange (e, isChecked) {
    dispatch('updatePreferences', 'highestPlaybackPriority', isChecked)
  }

  externalPlayerPathSelector () {
    const playerPath = this.props.state.saved.prefs.externalPlayerPath
    const playerName = this.props.state.getExternalPlayerName()

    const description = this.props.state.saved.prefs.openExternalPlayer
      ? `Torrent media files will always play in ${playerName}.`
      : `Torrent media files will play in ${playerName} if WebTorrent cannot play them.`

    return (
      React.createElement( Preference, null,
        React.createElement( 'p', null, description ),
        React.createElement( PathSelector, {
          dialog: {
            title: 'Select media player app',
            properties: ['openFile']
          }, onChange: this.handleExternalPlayerPathChange, title: 'External player', value: playerPath })
      )
    )
  }

  handleExternalPlayerPathChange (filePath) {
    dispatch('updatePreferences', 'externalPlayerPath', filePath)
  }

  autoAddTorrentsCheckbox () {
    return (
      React.createElement( Preference, null,
        React.createElement( Checkbox, {
          className: 'control', checked: this.props.state.saved.prefs.autoAddTorrents, label: 'Watch for new .torrent files and add them immediately', onCheck: (e, value) => { this.handleAutoAddTorrentsChange(e, value) } })
      )
    )
  }

  handleAutoAddTorrentsChange (e, isChecked) {
    const torrentsFolderPath = this.props.state.saved.prefs.torrentsFolderPath
    if (isChecked && !torrentsFolderPath) {
      alert('Select a torrents folder first.') // eslint-disable-line
      e.preventDefault()
      return
    }

    dispatch('updatePreferences', 'autoAddTorrents', isChecked)

    if (isChecked) {
      dispatch('startFolderWatcher')
      return
    }

    dispatch('stopFolderWatcher')
  }

  torrentsFolderPathSelector () {
    const torrentsFolderPath = this.props.state.saved.prefs.torrentsFolderPath

    return (
      React.createElement( Preference, null,
        React.createElement( PathSelector, {
          dialog: {
            title: 'Select folder to watch for new torrents',
            properties: ['openDirectory']
          }, onChange: this.handleTorrentsFolderPathChange, title: 'Folder to watch', value: torrentsFolderPath })
      )
    )
  }

  handleTorrentsFolderPathChange (filePath) {
    dispatch('updatePreferences', 'torrentsFolderPath', filePath)
  }

  setDefaultAppButton () {
    const isFileHandler = this.props.state.saved.prefs.isFileHandler
    if (isFileHandler) {
      return (
        React.createElement( Preference, null,
          React.createElement( 'p', null, "WebTorrent is your default torrent app. Hooray!" )
        )
      )
    }
    return (
      React.createElement( Preference, null,
        React.createElement( 'p', null, "WebTorrent is not currently the default torrent app." ),
        React.createElement( RaisedButton, {
          className: 'control', onClick: this.handleSetDefaultApp, label: 'Make WebTorrent the default' })
      )
    )
  }

  handleStartupChange (e, isChecked) {
    dispatch('updatePreferences', 'startup', isChecked)
  }

  setStartupCheckbox () {
    if (config.IS_PORTABLE) {
      return
    }

    return (
      React.createElement( Preference, null,
        React.createElement( Checkbox, {
          className: 'control', checked: this.props.state.saved.prefs.startup, label: 'Open WebTorrent on startup', onCheck: this.handleStartupChange })
      )
    )
  }

  soundNotificationsCheckbox () {
    return (
      React.createElement( Preference, null,
        React.createElement( Checkbox, {
          className: 'control', checked: this.props.state.saved.prefs.soundNotifications, label: 'Enable sounds', onCheck: this.handleSoundNotificationsChange })
      )
    )
  }

  handleSoundNotificationsChange (e, isChecked) {
    dispatch('updatePreferences', 'soundNotifications', isChecked)
  }

  handleSetDefaultApp () {
    dispatch('updatePreferences', 'isFileHandler', true)
  }

  render () {
    const style = {
      color: colors.grey400,
      marginLeft: 25,
      marginRight: 25
    }
    return (
      React.createElement( 'div', { style: style },
        React.createElement( PreferencesSection, { title: 'Folders' },
          this.downloadPathSelector(),
          this.autoAddTorrentsCheckbox(),
          this.torrentsFolderPathSelector()
        ),
        React.createElement( PreferencesSection, { title: 'Playback' },
          this.openExternalPlayerCheckbox(),
          this.externalPlayerPathSelector(),
          this.highestPlaybackPriorityCheckbox()
        ),
        React.createElement( PreferencesSection, { title: 'Default torrent app' },
          this.setDefaultAppButton()
        ),
        React.createElement( PreferencesSection, { title: 'General' },
          this.setStartupCheckbox(),
          this.soundNotificationsCheckbox()
        )
      )
    )
  }
}

class PreferencesSection extends React.Component {
  static get propTypes () {
    return {
      title: PropTypes.string
    }
  }

  render () {
    const style = {
      marginBottom: 25,
      marginTop: 25
    }
    return (
      React.createElement( 'div', { style: style },
        React.createElement( Heading, { level: 2 }, this.props.title),
        this.props.children
      )
    )
  }
}

class Preference extends React.Component {
  render () {
    const style = { marginBottom: 10 }
    return (React.createElement( 'div', { style: style }, this.props.children))
  }
}

module.exports = PreferencesPage
